Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(472)

Unified Diff: third_party/WebKit/Source/core/layout/ng/ng_layout_input_node.h

Issue 2702403003: [layoutng] Split NGLayoutResult out of NGPhysicalFragment (Closed)
Patch Set: rebased Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/layout/ng/ng_layout_input_node.h
diff --git a/third_party/WebKit/Source/core/layout/ng/ng_layout_input_node.h b/third_party/WebKit/Source/core/layout/ng/ng_layout_input_node.h
index ed282c8176d80d721885162ebee8947cc7259833..0c36cdefccd5759495e1b6912b7853aa6553fc1b 100644
--- a/third_party/WebKit/Source/core/layout/ng/ng_layout_input_node.h
+++ b/third_party/WebKit/Source/core/layout/ng/ng_layout_input_node.h
@@ -12,7 +12,7 @@ namespace blink {
class LayoutObject;
class NGConstraintSpace;
-class NGPhysicalFragment;
+class NGLayoutResult;
// Represents the input to a layout algorithm for a given node. The layout
// engine should use the style, node type to determine which type of layout
@@ -24,8 +24,8 @@ class CORE_EXPORT NGLayoutInputNode
virtual ~NGLayoutInputNode(){};
- // Performs layout on this input node, will return a new fragment.
- virtual RefPtr<NGPhysicalFragment> Layout(NGConstraintSpace*) = 0;
+ // Performs layout on this input node, will return the layout result.
+ virtual RefPtr<NGLayoutResult> Layout(NGConstraintSpace*) = 0;
// Returns the next sibling.
virtual NGLayoutInputNode* NextSibling() = 0;

Powered by Google App Engine
This is Rietveld 408576698